==> beast-privilege-api-3.0.2-GS-20250812.060525-25-sources.jar: com/thebeastshop/privilege/vo/FlowerPackageCarVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class FlowerPackageCarVO implements Serializable  {
    private Integer id;
    private String number;
    private String carNumber;

    private String driverName;
    private String driverPhone;
    private Date createTime;
    private Integer createId;
    private String createMan;
    private Date updateTime;

    private Integer sendedCount;

    private List<FlowerPackageCarDetailVO> packageCarDetailVOs;

    private List<FlowerPackageVO> packageVOs;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getNumber() {
        return number;
    }

    public void setNumber(String number) {
        this.number = number;
    }

    public String getCarNumber() {
        return carNumber;
    }

    public void setCarNumber(String carNumber) {
        this.carNumber = carNumber;
    }



    public String getDriverName() {
        return driverName;
    }

    public void setDriverName(String driverName) {
        this.driverName = driverName;
    }

    public String getDriverPhone() {
        return driverPhone;
    }

    public void setDriverPhone(String driverPhone) {
        this.driverPhone = driverPhone;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Integer getCreateId() {
        return createId;
    }

    public void setCreateId(Integer createId) {
        this.createId = createId;
    }

    public String getCreateMan() {
        return createMan;
    }

    public void setCreateMan(String createMan) {
        this.createMan = createMan;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Integer getSendedCount() {
        return sendedCount;
    }

    public void setSendedCount(Integer sendedCount) {
        this.sendedCount = sendedCount;
    }
    public List<FlowerPackageCarDetailVO> getPackageCarDetailVOs() {
        return packageCarDetailVOs;
    }

    public void setPackageCarDetailVOs(List<FlowerPackageCarDetailVO> packageCarDetailVOs) {
        this.packageCarDetailVOs = packageCarDetailVOs;
    }

    public List<FlowerPackageVO> getPackageVOs() {
        return packageVOs;
    }

    public void setPackageVOs(List<FlowerPackageVO> packageVOs) {
        this.packageVOs = packageVOs;
    }
}

==> beast-privilege-api-3.0.11-GS-20250908.040058-15-sources.jar: com/thebeastshop/privilege/vo/FlowerPackageCarVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class FlowerPackageCarVO implements Serializable  {
    private Integer id;
    private String number;
    private String carNumber;

    private String driverName;
    private String driverPhone;
    private Date createTime;
    private Integer createId;
    private String createMan;
    private Date updateTime;

    private Integer sendedCount;

    private Integer status;


    private String qcUrl;

    private List<FlowerPackageCarDetailVO> packageCarDetailVOs;

    private List<FlowerPackageVO> packageVOs;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getNumber() {
        return number;
    }

    public void setNumber(String number) {
        this.number = number;
    }

    public String getCarNumber() {
        return carNumber;
    }

    public void setCarNumber(String carNumber) {
        this.carNumber = carNumber;
    }



    public String getDriverName() {
        return driverName;
    }

    public void setDriverName(String driverName) {
        this.driverName = driverName;
    }

    public String getDriverPhone() {
        return driverPhone;
    }

    public void setDriverPhone(String driverPhone) {
        this.driverPhone = driverPhone;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Integer getCreateId() {
        return createId;
    }

    public void setCreateId(Integer createId) {
        this.createId = createId;
    }

    public String getCreateMan() {
        return createMan;
    }

    public void setCreateMan(String createMan) {
        this.createMan = createMan;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Integer getSendedCount() {
        return sendedCount;
    }

    public void setSendedCount(Integer sendedCount) {
        this.sendedCount = sendedCount;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getQcUrl() {
        return qcUrl;
    }

    public void setQcUrl(String qcUrl) {
        this.qcUrl = qcUrl;
    }

    public List<FlowerPackageCarDetailVO> getPackageCarDetailVOs() {
        return packageCarDetailVOs;
    }

    public void setPackageCarDetailVOs(List<FlowerPackageCarDetailVO> packageCarDetailVOs) {
        this.packageCarDetailVOs = packageCarDetailVOs;
    }

    public List<FlowerPackageVO> getPackageVOs() {
        return packageVOs;
    }

    public void setPackageVOs(List<FlowerPackageVO> packageVOs) {
        this.packageVOs = packageVOs;
    }
}
